CHANGES
=======

0.3 (unreleased)
----------------

0.2.5 (2011-07-08)
------------------

- Fixed dependency on pivotal-py to >=0.1.3
- Changed import path for Pivotal

0.2.4 (2011-07-08)
------------------

- Fixed dependency on pivotal-py to >=0.1.2

0.2.3 (2011-07-07)
------------------

- A bugfix release due to bad packaging when uploading to PyPI. Sorry to anyone who experienced problems!

